VERSION 1.0 CLASS
BEGIN
  MultiUse = -1  'True
END
Attribute VB_Name = "cSections"
Attribute VB_Creatable = False
Attribute VB_Exposed = False
' SESIN - Subway Environment Simulation Input Manager
' Volpe Transportation Systems Center
' Written by: ICF Kaiser Engineers, Oakland, CA
' Orig: Jan '97

Option Explicit

'       Sections.cls

' This class is a collection for handling Line Sections
' It provides specialized handling to safeguard the association
' between sections and segments and provides management of the
' default segment definition and the segment cut/copy/paste buffer

Private colSects As New Collection

Private DefaultSect As New cSection
Private BufferSect As cSection
'
'  This is the most central spot for the Default Segment
'
Public DefaultSeg As cSegment

Public Function Add(ni As Integer) As cSection
' Add a new section to the collection
' Return a pointer to the new section
Dim ss As cSection
    Set ss = New cSection
    ss.XCopy DefaultSect
    ' add it to the collection
    If ni > 0 Then
        colSects.Add Item:=ss, before:=ni
    Else
        colSects.Add Item:=ss
    End If
    Set Add = ss
End Function
Public Sub Copy(isect As Integer)
' Copy the contents of the specified record to the buffer
    Set BufferSect = Nothing    ' clear any previous buffer
    Set BufferSect = New cSection  ' set a new one
    BufferSect.XCopy colSects.Item(isect) ' copy contents
    BufferSect.id = 0
    
End Sub

Public Sub SectList(gg As Grid)
Dim ss As cSection
    For Each ss In colSects
        With ss
        gg.AddItem Str$(.id) + Chr$(9) + Str$(.StartNode) + _
           Chr$(9) + Str$(.StopNode) + Chr$(9) + Str$(.nLSegs) + Chr$(9) + .InitAir
        End With
    Next
    If gg.Rows > 1 Then gg.RemoveItem 0
    
End Sub

Public Sub NodeList(nn() As Integer)
' Called  by buildnodes to get a list of nodes used
' nn(1000,5) with n,0 = # elements connected to node n
Dim ss As cSection
Dim ni As Integer, nk As Integer

    For Each ss In colSects
        With ss
            ni = .StartNode
            nk = nn(ni, 0) + 1
            nn(ni, 0) = nk
            nn(ni, nk) = .id
            ni = .StopNode
            nk = nn(ni, 0) + 1
            nn(ni, 0) = nk
            nn(ni, nk) = .id
        End With
    Next
    
End Sub

Public Sub SectShortList(LL As ListBox, rr As ListBox)
' Make a list of all sections NOT in rr
Dim ss As cSection, nn As Integer, ii As Integer
Dim sid As Integer
    LL.Clear
    nn = rr.ListCount - 1
    For Each ss In colSects
        sid = ss.id
        For ii = 0 To nn
            If Abs(Val(rr.List(ii))) = sid Then Exit For
        Next ii
        If ii > nn Then LL.AddItem sid
    Next
    
End Sub

Public Sub SetDefault(isect As Integer)
' Copy the contents of the specified record to the buffer
    Set DefaultSect = Nothing    ' clear any previous buffer
    DefaultSect.XCopy colSects.Item(isect)    ' copy contents
    DefaultSect.id = 0
    
End Sub

Public Property Get Count() As Integer
' Returns the number of sections in the collection
    Count = colSects.Count
    
End Property


Public Sub Cut(isect As Integer)
' copy the section to the buffer then delete it from the list
    Copy isect
    colSects.Remove isect
End Sub

Public Function Delete(ni As Integer)
    colSects.Remove ni
    
End Function

Public Function Paste(isect As Integer) As cSection
' insert a copy of the buffer section at location
' isect
Dim ss As cSection
    Set ss = New cSection
    ss.XCopy BufferSect
    ss.id = 0
    If isect < colSects.Count Then
        colSects.Add Item:=ss, before:=isect
    Else
        colSects.Add Item:=ss   ' at end
    End If
    Set Paste = ss
End Function

Public Function ReadSections(nn As Integer) As Boolean
' Read nn line sections from input file
' The segments are not initialized at this point
' since they will be read from the file later
Dim ii As Integer
Dim ss As cSection
    On Error GoTo ReadErr
    ReadSections = True
    For ii = 1 To nn
        Set ss = New cSection
        ss.ReadData
        colSects.Add ss
        Set ss = Nothing
    Next ii
    Exit Function
ReadErr:
    ReadSections = False
End Function

Public Function ReadSegments() As Boolean
' Reads segment data for line Sections from the data file
Dim Sect As cSection
    ReadSegments = False
    For Each Sect In colSects
        If Not Sect.ReadSegs Then Exit Function
    Next
    ReadSegments = True

End Function


Public Function Section(sid) As cSection
    Set Section = colSects.Item(sid)
    
End Function

Public Sub SegCol(cc As Collection)
' load the segments into the collection
' Similar to SegList except without the grid
Dim i1 As Integer, j1 As Integer
Dim mm As Integer, nn As Integer
Dim ss As cSection, Seg As cSegment

    For Each ss In colSects
        nn = ss.id
        j1 = ss.nLSegs
        For i1 = 1 To j1
            Set Seg = ss.Segment(i1)
            mm = Seg.id
            cc.Add Seg
        Next i1
    Next

End Sub

Public Sub SegList(gg As Grid, cc As Collection)
' load the segment id's into the grid control
Dim i1 As Integer, j1 As Integer
Dim mm As Integer, nn As Integer
Dim ss As cSection, Seg As cSegment

    For Each ss In colSects
        nn = ss.id
        j1 = ss.nLSegs
        For i1 = 1 To j1
            Set Seg = ss.Segment(i1)
            mm = Seg.id
            If mm = 0 Then
                mm = ss.id
                Seg.id = mm
            End If
            gg.AddItem Str(nn) & Chr(9) & Str(mm)
            cc.Add Seg
        Next i1
    Next
    If gg.Rows > 1 Then gg.RemoveItem 0

End Sub

Public Sub SegZList(cc As Collection)
'  Add all segments to collection cc as ZSect objects indexed
'  by the string of the id
Dim i1 As Integer, j1 As Integer
Dim XX As Zsect
Dim ss As cSection
Dim sss As String
    
    For Each ss In colSects
        j1 = ss.nLSegs
        For i1 = 1 To j1
            sss = Str$(ss.Segment(i1).id)
            Set XX = New Zsect
            XX.sid = sss
            XX.vent = False
            XX.used = False
            cc.Add XX, sss
        Next i1
    Next ss

End Sub

Public Sub WriteSections()
' loop through the collection to write each section
Dim ss As cSection
    For Each ss In colSects
        ss.WriteData
    Next
End Sub

Private Sub Class_Initialize()
' Set up the default segment and section
Dim ss As cSubSeg
Dim sx As cSegment

    Set DefaultSeg = New cSegment
    With DefaultSeg
        .id = 1
        .sType = 1
        .Title = "New"
        .sLen = Zero
        .XArea = Zero
        .Height = Zero
        .Fire = False
        .HLFP = Zero
        .HLFN = Zero
        .HLBP = Zero
        .HLBN = Zero
        .WWS = Zero
        .NSubs = 1

        .Perim(1) = Zero
        .Rough(1) = Zero

        .WThk = Zero
        .WDist = Zero
        .WCond = Zero
        .WDiff = Zero
        .SCond = Zero
        .SDiff = Zero
        .TSink = Zero
        ' Subsegment (Wall) Data
        Set ss = .AddSubSeg
        ss.setSubSeg 1, 1, 0, 0, 0
        ' steady state heat source
        .NSSHS = 0
    End With
    
    With DefaultSect
        .id = 1
        .StartNode = 1
        .StopNode = 2
        .InitAir = Zero
        Set sx = .AddSeg
    End With
    sx.XCopy DefaultSeg
    
    Set BufferSect = Nothing

End Sub

Private Sub Class_Terminate()
Dim i
    Set DefaultSect = Nothing
    Set BufferSect = Nothing
    Set DefaultSeg = Nothing
    For i = 1 To colSects.Count
        colSects.Remove 1
    Next
End Sub


