VERSION 1.0 CLASS
BEGIN
  MultiUse = -1  'True
  Persistable = 0  'NotPersistable
  DataBindingBehavior = 0  'vbNone
  DataSourceBehavior  = 0  'vbNone
  MTSTransactionMode  = 0  'NotAnMTSObject
END
Attribute VB_Name = "cVents"
Attribute VB_GlobalNameSpace = False
Attribute VB_Creatable = False
Attribute VB_PredeclaredId = False
Attribute VB_Exposed = False
' SESIN - Subway Environment Simulation Input Manager
' Volpe Transportation Systems Center
' Written by: ICF Kaiser Engineers, Oakland, CA
' Orig: Jan '97

Option Explicit

'       cVents.cls
' This class is a collection for handling Line Sections
' It provides specialized handling to safeguard the association
' between sections and segments and provides management of the
' default segment definition and the cut/copy/paste segment buffer.

Private colVents As New Collection
Private BufferVent As cVent
Public DefaultVent As New cVent
'
Public DefaultShaft As cVShaft

Public Function Add(ni As Integer) As cVent
' Add a new vent section to the collection
' Return a pointer to the new section
Dim newvent As New cVent
    Set newvent = New cVent
    newvent.XCopy DefaultVent
    ' add it to the collection
    If ni > 0 Then
        colVents.Add Item:=newvent, before:=ni
    Else
        colVents.Add Item:=newvent
    End If
    Set Add = newvent
    
End Function

Public Function Copy(isect As Integer)
' Copy the contents of the specified record to the buffer
    Set BufferVent = Nothing    ' clear any previous buffer
    Set BufferVent = New cVent  ' set a new one
    BufferVent.XCopy colVents(isect) ' copy contents
    BufferVent.id = 0
    
End Function

Public Sub VentList(gg As Grid)
Dim vv As cVent
    For Each vv In colVents
        With vv
        gg.AddItem Str$(.id) + Chr$(9) + Str$(.StartNode) + _
           Chr$(9) + Str$(.StopNode) + Chr$(9) + .InitAir
        End With
    Next
    If gg.Rows > 1 Then gg.RemoveItem 0
    
End Sub

Public Sub NodeList(nn() As Integer)
' Called  by buildnodes to get a list of nodes used
' nn(1000,5) with n,0 = # elements connected to node n
Dim ss As cVent
Dim ni As Integer, nk As Integer
    For Each ss In colVents
        With ss
            ni = .StartNode
            nk = nn(ni, 0) + 1
            nn(ni, 0) = nk
            nn(ni, nk) = -.id
            ni = .StopNode
            nk = nn(ni, 0) + 1
            nn(ni, 0) = nk
            nn(ni, nk) = -.id
        End With
    Next
    
End Sub

Public Sub SetDefault(ivent As Integer)
' Copy the contents of the specified record to the buffer
    Set DefaultVent = Nothing    ' clear any previous buffer
    DefaultVent.XCopy colVents.Item(ivent)    ' copy contents
    DefaultVent.id = 0
        
End Sub

Public Property Get Count() As Integer
' Returns the number of sections in the collection
    Count = colVents.Count
    
End Property


Public Sub Cut(ivent As Integer)
' copy the vent to the buffer then delete it from the list
    Copy ivent
    colVents.Remove ivent
End Sub

Public Function Paste(ivent As Integer) As cVent
' insert a copy of the buffer vent at location
' isect
Dim ss As cVent
    Set ss = New cVent
    ss.XCopy BufferVent
    ss.id = 0
    If ivent < colVents.Count Then
        colVents.Add Item:=ss, before:=ivent
    Else
        colVents.Add Item:=ss   ' at end
    End If
    Set Paste = ss
End Function

Public Function Delete(ni As Integer)
    colVents.Remove ni
    
End Function


Public Function ReadVShafts() As Boolean
' Loop through vents to read the shaft data
Dim vent As cVent
    ReadVShafts = False
    For Each vent In colVents
        If Not vent.uVShaft.ReadData Then Exit Function
        Set vent.uVShaft.Daddy = vent
    Next
    ReadVShafts = True
End Function

Public Function ReadVents(nn As Integer) As Boolean
' Read nn vent sections from input file
Dim ii As Integer
Dim vsec As cVent
    ReadVents = False
    For ii = 1 To nn
        Set vsec = New cVent
        If Not vsec.ReadFile Then Exit Function
        colVents.Add vsec
        Set vsec = Nothing
    Next ii
    ReadVents = True
End Function

Public Sub WriteVents()
' loop through the collection to write each section
Dim ss As cVent
    For Each ss In colVents
        ss.WriteData
    Next
End Sub


Public Function vent(Vid) As cVent
    Set vent = colVents.Item(Vid)
    
End Function

Public Sub WriteVShafts()
' Loop through the vents to write shaft data
Dim vv As cVent
    For Each vv In colVents
        vv.uVShaft.WriteData
    Next
End Sub

Public Sub VentZList(CC As Collection)
' load the shafts into zone section objects in the collection cc
' use the string of the shaft id as the key in the collection
Dim ss As cVent, sss As String
Dim XX As Zsect

    For Each ss In colVents
        Set XX = New Zsect
        sss = Str$(ss.uVShaft.id)
        XX.sid = sss
        XX.vent = True
        XX.used = False
        CC.Add XX, sss
    Next

End Sub

Public Sub VShaftList(gg As Grid, CC As Collection)
' load the shaft id's into the grid control and its associated collection
Dim mm As Integer, nn As Integer
Dim ss As cVent, shaft As cVShaft

    For Each ss In colVents
        nn = ss.id
        Set shaft = ss.uVShaft
        mm = shaft.id
        If mm = 0 Then
            mm = nn
            shaft.id = mm
        End If
        gg.AddItem Str(nn) & Chr(9) & Str(mm)
        CC.Add shaft
    Next
    If gg.Rows > 1 Then gg.RemoveItem 0

End Sub

Public Sub FanList(gg As Grid, CC As Collection)
' load the shaft id's into the grid control and its associated collection
Dim mm As Integer, nn As Integer, nf As Integer
Dim ss As cVent, shaft As cVShaft, ffan As cFan
Dim fdir As String
    For Each ss In colVents
        nn = ss.id
        Set shaft = ss.uVShaft
        mm = shaft.id
        nf = shaft.FanType
        If nf > 0 Then
            Set ffan = SESDS.Fans.Fan(nf)
            Select Case shaft.FanDir
            Case -1
                fdir = "Supply"
            Case 0
                fdir = "Off"
            Case 1
                fdir = "Exhaust"
            Case Else
                fdir = "Undefined"
            End Select
            
            gg.AddItem Str(nn) & "-" & Str(mm) & Chr(9) & shaft.Title & Chr(9) & _
                ffan.id & Chr(9) & shaft.FanOn & Chr(9) & shaft.FanOff & _
                Chr(9) & fdir
            
            CC.Add shaft
        End If
    Next
    If gg.Rows > 1 Then gg.RemoveItem 0

End Sub

Private Sub Class_Initialize()
' Set up the default section
Dim vs As cVentSeg
    Set DefaultShaft = New cVShaft
    With DefaultShaft
        .id = 0
        .Title = "New"
        .VType = 1
'        .NSeg = 1
        .NSubSeg = 1
        .Grate = "0."
        .VGrate = "0."
        .WSTemp = "0."
        .TDB0 = "0."
        .TWB0 = "0."
        .StackHt = "0."
        .FanType = 0
        .FanOn = "0."
        .FanOff = "0."
        .FanDir = 0
        Set vs = .AddVSeg
        vs.setVSeg "10.", "10.", "10.", "0.", "0.", "0.", "0."
    End With
    With DefaultVent
        .id = 1
        .StartNode = 1
        .StopNode = 2
        .InitAir = Zero
        .uVShaft.XCopy DefaultShaft
    End With

End Sub

Private Sub Class_Terminate()
Dim i
    Set DefaultVent = Nothing
    Set DefaultShaft = Nothing
    For i = 1 To colVents.Count
        colVents.Remove 1
    Next
End Sub

