Attribute VB_Name = "modMisc"
' SESIN - Subway Environment Simulation Input Manager
' Volpe Transportation Systems Center
' Written by: ICF Kaiser Engineers, Oakland, CA
' Orig: Jan '97

Option Explicit

'       Misc.bas

' This is the main program module, containing Sub MAIN
' routine which is executed at startup and other global
' routines shared by all modules as well as global data
' including the dataset object for the current file.

' This is THE Dataset
Public SESDS As SESDataSet
'
'   Dirty File Flag - indicates changed data
Global FileDirty As Boolean

'  Table Row & Column placeholders
Public grow As Integer, gcol As Integer

' Other handy stuff
Public Const Zero As String * 10 = "0."
Public HomeDir As String

Global Const ASC_ENTER = 13  ' ASCII code of ENTER key
' Array for Sentinel Prompt Strings

Declare Sub SetWindowPos Lib "User32" (ByVal hWnd As Long, ByVal hWndInsertAfter As Long, ByVal X As Long, ByVal Y As Long, ByVal cx As Long, ByVal cy As Long, ByVal wFlags As Long)

Global Const SWP_NOMOVE = 2
Global Const SWP_NOSIZE = 1
Global Const FLAGS = SWP_NOMOVE Or SWP_NOSIZE
Global Const HWND_TOPMOST = -1
Global Const NA = 9.1E-91

Public Function IStr(ii As Integer) As String
' returns a 10 character string with ii and a .
Dim ss As String * 10
    ss = Str(ii) + "          "
    IStr = ss
    
End Function

Public Function LStr(ii As Long) As String
' returns a 10 character string with ii and a .
Dim ss As String * 10
    ss = Str(ii) + ".         "
    LStr = ss
    
End Function

Sub Main()
    ' This is the startup Routine for the program
    ' This routine displays the ABOUT dialog box as
    ' a splash screen, then initializes a new data set
    ' and displays the main form (frmMain).
Dim kk As Integer, jj As Integer
    
    HomeDir = App.Path
    App.HelpFile = HomeDir + "\SESIN.HLP"
    ' Initialize the random number generator
    Randomize

    About.Timer1.Enabled = True ' set the timer so it will auto clear
    About.Show
    About.Refresh   ' Refresh to show it all NOW

    ' Initialize a Dataset
    Set SESDS = New SESDataSet
    
    ' Load frmMain
    frmMain.Show
    About.cmdOkay.SetFocus

End Sub

' Common Routines for SES Input Program
Function ChkVal(ByRef Var, vlo, vhi)
' Check validity for Real Numbers
' Returns TRUE for ERROR!!!!
' Check for valid numeric format
' The range values are assumed to be inclusive
Dim V As Single
    ChkVal = False
    If Trim(Var) = "" Then Exit Function
    If Not IsNumeric(Var) Then
        ChkVal = True
        MsgBox Var + Chr(10) + "is not numeric", 48, "Invalid entry"
    ' Check that Var falls between Vlo & Vhi inclusive
    Else
        V = Val(Var)
        If (V < vlo Or V > vhi) Then
            ChkVal = True
            If MsgBox("Allowable Range:" + Chr(10) + Str$(vlo) + _
                " to" + Str$(vhi) + Chr(10) + "Try again?", 52, _
                "Invalid Entry") = 7 Then ChkVal = False
        Else
            ChkVal = False
            If InStr(Var, ".") = 0 Then Var = RTrim(Var) + "."
        End If
    End If
End Function

Function ChkInt(Var, vlo, vhi)
' Check validity for Integers
' Returns TRUE for ERROR!!!!
' Check for valid numeric format
' The range values are assumed to be inclusive
Dim N As Integer, V As Single
    ChkInt = False
    If Trim(Var) = "" Then Exit Function
    If Not IsNumeric(Var) Then
        ChkInt = True
        MsgBox Var + Chr(10) + "is not numeric", 48, "Invalid entry"
    ' Check that Var falls between Vlo & Vhi inclusive
    Else
        N = Val(Var)
        If (N < vlo Or N > vhi) Then
            If MsgBox("Allowable Range:" + Chr(10) + Str$(vlo) + _
               " to" + Str$(vhi) + Chr(10) + "Try again?", 52, _
               "Invalid Entry") <> 7 Then ChkInt = True
        ElseIf (N <> Val(Var)) Then
            MsgBox "Integer Value Required", 48, "Invalid Entry"
            ChkInt = True
        End If
        Var = Val(N)
    End If
End Function

Function getrec(Grid As Control) As String
' Gets the contents of the current row of the
' Grid and formats it into a tab delimited string
    Dim i%, j%, s$
    i% = Grid.Col
    Grid.Col = 0
    s$ = Grid.Text
    For j% = 1 To Grid.Cols - 1
        Grid.Col = j%
        s$ = s$ + Chr(9) + Grid.Text
    Next j%
    Grid.Col = i%
    getrec = s$
End Function

Public Sub grid_text_move(Grid As Control, TextBox As Control)
'This routine positions the edit control (textbox) over the current
' grid cell and copies the cell content into the textbox.
' This provides basic editing capability to the standard Grid Control
    Dim X As Single, Y As Single, h As Single, w As Single
       ' Save the position of the grids Row and Col for later:
       ' Note: grow and gcol are global variables
      grow = Grid.Row
      gcol = Grid.Col
      X = Grid.Left + Grid.ColPos(gcol)
      Y = Grid.Top + Grid.RowPos(grow)
      w = Grid.ColWidth(gcol) - 2 * Screen.TwipsPerPixelX
      h = Grid.RowHeight(grow) - 2 * Screen.TwipsPerPixelY

      TextBox.Move X + 2 * Screen.TwipsPerPixelX, Y + 2 * Screen.TwipsPerPixelY, w, h
      ' Make text box same size as current grid cell:
      TextBox.Width = Grid.ColWidth(gcol) - 2 * Screen.TwipsPerPixelX
      TextBox.Height = Grid.RowHeight(grow) - 2 * Screen.TwipsPerPixelY
      ' Transfer the grid cell text:
      TextBox.Text = RTrim(Grid.Text)
      TextBox.SelStart = 0
      TextBox.SelLength = Len(TextBox.Text)
      ' Show the text box:
      TextBox.Visible = True
      TextBox.ZOrder 0

End Sub
Public Sub txtKeyDown(gg As Grid, KeyCode As Integer, Shift As Integer)
' Handle Up Arrow and Down Arrow Actions for grids
  With gg
    Select Case KeyCode
    Case vbKeyUp
      If .Row > .FixedRows Then
        .Row = .Row - 1
        .SelStartRow = .Row
        .SelEndRow = .Row
      End If
      .SetFocus
    Case vbKeyDown
      If .Row < .Rows - 1 Then
        .Row = .Row + 1
        .SelStartRow = .Row
        .SelEndRow = .Row
      End If
      .SetFocus
    End Select
  End With
End Sub

Public Sub txtKeyPress(gg As Grid, KeyAscii As Integer)
' Handle Enter key in grids
    If KeyAscii = ASC_ENTER Then
    With gg
        If .Col < .Cols - 1 Then
            .Col = .Col + 1
        Else
            If .Row = .Rows - 1 Then
                .AddItem " "
            End If
            .Row = .Row + 1
            .Col = .FixedCols
        End If
        .SelStartCol = .Col
        .SelEndCol = .Col
        .SelStartRow = .Row
        .SelEndRow = .Row
        .SetFocus
    End With
    KeyAscii = 0  ' Prevents beep
    End If
End Sub

Public Sub SizeIt(FFF As Form)
' Handle the resizing of all controls on a
' form for resize event processing.

' In order to use this routine, each form that
' calls it must maintain certain information,
' specifically, the old width and height: OldW & OldH
' as public variables

' First calculate the scale factors
Dim xs As Single, YS As Single, XX As Single
Dim CC As Control
Dim ii As Integer, jj As Integer, kk As Integer

    If FFF.WindowState = 1 Then Exit Sub
    xs = FFF.Width / FFF.oldW
    YS = FFF.Height / FFF.oldH
    FFF.oldH = FFF.Height
    FFF.oldW = FFF.Width
    
    For Each CC In FFF.Controls
        If TypeOf CC Is Line Then
            CC.X1 = CC.X1 * xs
            CC.X2 = CC.X2 * xs
            CC.Y1 = ((CC.Y1 - 45) * YS) + 45
            CC.Y2 = ((CC.Y2 - 45) * YS) + 45
        ElseIf TypeOf CC Is TextBox Or TypeOf CC Is Label _
            Or TypeOf CC Is CommandButton _
            Or TypeOf CC Is CheckBox Or TypeOf CC Is ListBox Then
              CC.Move CC.Left * xs, ((CC.Top - 45) * YS) + 45, CC.Width * xs, CC.Height * YS
            If frmMain.TheFontSize > 0 Then
                CC.Font.Name = frmMain.TheFont
                CC.Font.Size = frmMain.TheFontSize
            End If
        ElseIf TypeOf CC Is SSTab Then
            CC.Left = CC.Left * xs
            CC.Top = ((CC.Top - 45) * YS) + 45
            CC.Width = CC.Width * xs
            CC.Height = ((CC.Height - 45) * YS) + 45
        ElseIf TypeOf CC Is SSPanel Then
            If CC.Left < -50000 Then
              XX = (CC.Left + 76005) * xs - 76005
              CC.Move XX, ((CC.Top - 45) * YS) + 45, CC.Width * xs, CC.Height * YS
            Else
              CC.Move CC.Left * xs, ((CC.Top - 45) * YS) + 45, CC.Width * xs, CC.Height * YS
            End If
        ElseIf TypeOf CC Is ComboBox Then
            If CC.Style = 0 Or CC.Style = 2 Then
              CC.Move CC.Left * xs, ((CC.Top - 45) * YS) + 45, CC.Width * xs
            Else
              CC.Move CC.Left * xs, ((CC.Top - 45) * YS) + 45, CC.Width * xs, CC.Height * YS
            End If
            If frmMain.TheFontSize > 0 Then
                CC.Font.Name = frmMain.TheFont
                CC.Font.Size = frmMain.TheFontSize
            End If
        ElseIf TypeOf CC Is Grid Then
            CC.Move CC.Left * xs, ((CC.Top - 45) * YS) + 45, CC.Width * xs, CC.Height * YS
            For ii = 0 To CC.Cols - 1
                CC.ColWidth(ii) = CC.ColWidth(ii) * xs
            Next
            If frmMain.TheFontSize > 0 Then
                CC.Font.Name = frmMain.TheFont
                CC.Font.Size = frmMain.TheFontSize
            End If
        ElseIf TypeOf CC Is Menu Or TypeOf CC Is StatusBar _
            Or TypeOf CC Is CommonDialog Or TypeOf CC Is Toolbar _
            Or TypeOf CC Is ImageList Then
        Else
            CC.Move CC.Left * xs, ((CC.Top - 45) * YS) + 45, CC.Width * xs, CC.Height * YS
        End If
    Next

End Sub

Function GetFour(t1, t2, t3, t4) As Boolean
' Read 4f10.0 input record  - (for shorter input records)
Dim LL$
    On Error GoTo InErr
    Line Input #1, LL$
    t1 = LTrim(Mid$(LL$, 1, 10))
    t2 = LTrim(Mid$(LL$, 11, 10))
    t3 = LTrim(Mid$(LL$, 21, 10))
    t4 = LTrim(Mid$(LL$, 31, 10))
    GetFour = True
    Exit Function
InErr:
    GetFour = False
    
End Function

Function GetLine(t1, t2, t3, t4, t5, t6, t7, t8) As Boolean
Dim ssl As String * 80
' Read 8f10.0 input record
    On Error GoTo InErr
    Line Input #1, ssl
    t1 = LTrim(Mid$(ssl, 1, 10))
    t2 = LTrim(Mid$(ssl, 11, 10))
    t3 = LTrim(Mid$(ssl, 21, 10))
    t4 = LTrim(Mid$(ssl, 31, 10))
    t5 = LTrim(Mid$(ssl, 41, 10))
    t6 = LTrim(Mid$(ssl, 51, 10))
    t7 = LTrim(Mid$(ssl, 61, 10))
    t8 = LTrim(Mid$(ssl, 71, 10))
    GetLine = True
    Exit Function
InErr:
    GetLine = False
End Function

Public Sub SplitFName(WholeName, DirName, FName)
Dim ii As Integer
    ii = Len(WholeName)
    While (Mid$(WholeName, ii, 1) <> "\")
        ii = ii - 1
    Wend
    DirName = Left$(WholeName, ii)
    FName = Mid$(WholeName, ii + 1)
    
End Sub

