VERSION 1.0 CLASS
BEGIN
  MultiUse = -1  'True
  Persistable = 0  'NotPersistable
  DataBindingBehavior = 0  'vbNone
  DataSourceBehavior  = 0  'vbNone
  MTSTransactionMode  = 0  'NotAnMTSObject
END
Attribute VB_Name = "cNodes"
Attribute VB_GlobalNameSpace = False
Attribute VB_Creatable = False
Attribute VB_PredeclaredId = False
Attribute VB_Exposed = False
' SESIN - Subway Environment Simulation Input Manager
' Volpe Transportation Systems Center
' Written by: ICF Kaiser Engineers, Oakland, CA
' Orig: Jan '97

Option Explicit
'       cNodes.cls
' This is the Collection of Nodes

Private colNodes As Collection

Private DefaultNode As cNode
Private BufferNode As cNode

Public Function Add(ni As Integer) As cNode
' Add a node to the collection at the specified location
Dim Node As cNode
    Set Node = New cNode
    If ni > 0 Then
        colNodes.Add Node, before:=ni
    Else
        colNodes.Add Node
    End If
    Node.XCopy DefaultNode
    Set Add = Node
    
End Function

Public Sub Copy(nn As Integer)
' Copy the specified node to NodeBuffer
    Set BufferNode = New cNode
    BufferNode.XCopy colNodes(nn)
    
End Sub

Public Sub Cut(nn As Integer)
' Copy the specified node to the node buffer and then
' Delete it from the collection
    Set BufferNode = New cNode
    BufferNode.XCopy colNodes(nn)
    colNodes.Remove nn
    
End Sub

Public Property Get Node(nn As Integer) As cNode
    If nn > 0 And nn <= colNodes.Count Then
        Set Node = colNodes(nn)
    Else
        Set Node = Nothing
    End If
End Property

Public Property Get BrCount() As Integer
'  Return the number of brached junctions
Dim nn As Integer, ii As Integer
    nn = 0
    For ii = 1 To colNodes.Count
        If colNodes(ii).Branched Then nn = nn + 1
    Next ii
    BrCount = nn
End Property

Public Property Get Count() As Integer
    Count = colNodes.Count
    
End Property

Public Sub Delete(indx As Integer)
    colNodes.Remove indx
    
End Sub

Public Sub NodeList(gg As Grid)
Dim ss As cNode
    gg.Rows = 1
    For Each ss In colNodes
        With ss
        gg.AddItem Str$(.id)
        End With
    Next
    If gg.Rows > 1 Then gg.RemoveItem 0

End Sub

Public Sub Paste(nn As Integer)
' Paste the node buffer at the specified location
Dim nx As New cNode
    nx.XCopy BufferNode
    colNodes.Add nx, before:=nn
    
End Sub

Public Function ReadNodes(nn As Integer) As Boolean
Dim ii As Integer
Dim nx As cNode
    ReadNodes = False
    For ii = 1 To nn
        Set nx = New cNode
        If Not nx.ReadData Then Exit Function
        colNodes.Add nx
    Next ii
    ReadNodes = True
End Function

Public Sub SetDefault(nn As Integer)
' Copy the current node to the default buffer
    Set DefaultNode = New cNode
    DefaultNode.XCopy colNodes(nn)
    
End Sub

Public Sub WriteNodes()
' Loop through the collection to write the
' data for each node
Dim ii As Integer
    For ii = 1 To colNodes.Count
        colNodes(ii).WriteData
    Next ii
End Sub

Public Sub BuildNodes()
' This procedure updates the node list from the
' Line & Vent Section data

' The array, Nodules, keeps track of the section numbers
' attached to each node, the first subscript is the node
' number, the second is for the sections. The (n,0) element
' holds the number of sections attached to node n.
Dim Nodules(1000, 5) As Integer
Dim ii As Integer, iID As Integer, ns As Integer
Dim iat As Integer, itt As Integer
Dim vv As Boolean   ' flag to indicate last sect is a vent
Dim nn As cNode

'  Loop through the line sections
    SESDS.Lines.NodeList Nodules
'  Then the vents
    SESDS.Vents.NodeList Nodules
    
'    Now loop through the existing nodes checking for changes
    For ii = colNodes.Count To 1 Step -1
        Set nn = colNodes(ii)
        iID = nn.id
        If Nodules(iID, 0) = 0 Then
            colNodes.Remove ii
        Else
            ' check that the number of sections is consistent with
            ' the currently indicated node type
            ns = Nodules(iID, 0)
            vv = Nodules(iID, ns) < 0
            iat = -1
            itt = -1
            Select Case nn.AType
            Case 0
                If ns = 1 Then
                    itt = 3
                ElseIf ns = 2 Then
                    itt = 1
                Else
                    NodeType ns, itt, iat, vv
                End If
            Case 1
                If ns <> 4 Then
                    NodeType ns, itt, iat, vv
                End If
            Case 2 To 5
                NodeType ns, itt, iat, vv
            Case 7
                If ns < 3 Then
                    NodeType ns, itt, iat, vv
                End If
            End Select
            '   set the element count to -1 after processing
            '   to indicate the node exists
            If iat > -1 Then
                
                nn.AType = iat
                If iat = 1 Then
                    nn.SetA1 Abs(Nodules(iID, 1)), Abs(Nodules(iID, 2)), Abs(Nodules(iID, 3)), Abs(Nodules(iID, 4)), "1."
                ElseIf iat > 1 Then
                    nn.SetA4 Abs(Nodules(iID, 1)), Abs(Nodules(iID, 2)), Abs(Nodules(iID, 3)), "1.", "20."
                End If
            End If
            If itt > -1 Then nn.TType = itt
            If ns > 0 Then Nodules(iID, 0) = -1
        End If
    Next ii
    
'   Now loop through Nodules to see if there are any left which
'   need to be added.
    For ii = 1 To 999
        If Nodules(ii, 0) > 0 Then
            ' New node, add to end of node list
            Set nn = SESDS.Nodes.Add(0)
            nn.id = ii
            ns = Nodules(ii, 0)
            vv = Nodules(ii, ns) < 0
            NodeType ns, itt, iat, vv
            nn.AType = iat
            nn.TType = itt
            If iat = 1 Then
                nn.SetA1 Abs(Nodules(ii, 1)), Abs(Nodules(ii, 2)), Abs(Nodules(ii, 3)), Abs(Nodules(ii, 4)), "1."
            ElseIf iat > 1 Then
                nn.SetA4 Abs(Nodules(ii, 1)), Abs(Nodules(ii, 2)), Abs(Nodules(ii, 3)), "1.", "20."
            End If
        End If
    Next ii
End Sub

Private Sub NodeType(ne As Integer, it As Integer, ia As Integer, vv As Boolean)
'  determine the probable node type of node ni
   Dim nn As Integer
    ia = 0
    it = 1
    Select Case ne
    Case 1
        it = 3
    Case 2
        ia = 0
    Case 3
        If vv Then
            ia = 3
        Else
            ia = 2
        End If
    Case 4
        If vv Then
            ia = 7
        Else
            ia = 1
        End If
    Case Else
        ia = 7
    End Select
End Sub

Private Sub Class_Initialize()
    Set colNodes = New Collection
    Set BufferNode = Nothing
    Set DefaultNode = New cNode
    With DefaultNode
        .AType = 0
        .TType = 1
        .SetA4 1, 2, 3, "1.", "10."
        .SetT2 Zero, Zero, Zero, Zero, Zero, Zero, Zero
    End With
End Sub


Private Sub Class_Terminate()
Dim ii As Integer
    For ii = 1 To colNodes.Count
        colNodes.Remove 1
    Next ii
    Set DefaultNode = Nothing
    Set BufferNode = Nothing
    
End Sub


