VERSION 1.0 CLASS
BEGIN
  MultiUse = -1  'True
  Persistable = 0  'NotPersistable
  DataBindingBehavior = 0  'vbNone
  DataSourceBehavior  = 0  'vbNone
  MTSTransactionMode  = 0  'NotAnMTSObject
END
Attribute VB_Name = "cSegment"
Attribute VB_GlobalNameSpace = False
Attribute VB_Creatable = False
Attribute VB_PredeclaredId = False
Attribute VB_Exposed = False
' SESIN - Subway Environment Simulation Input Manager
' Volpe Transportation Systems Center
' Written by: ICF Kaiser Engineers, Oakland, CA
' Orig: Jan '97

Option Explicit

'       Segment.cls

'  This is the Line segment class - cSegment

Private iID As Integer       ' Segment ID
Private iType As Integer        ' Segment Type
Private szTitle As String * 50  ' Description
Private sSLen As String * 10    ' Segment Length
Private sXArea As String * 10   ' Crossectional Area
Private sHeight As String * 10  ' Tunnel Height
Private iFire As Integer        ' Fire Segment Indicator
    ' Head Losses
Private sHLFP As String * 10    ' Forward Direction Positive Flow
Private sHLFN As String * 10    ' Forward - Negative
Private sHLBP As String * 10    ' Reverse - Positive
Private sHLBN As String * 10    ' Reverse - Negative
Private sWWS As String * 10     ' percent wetted wall surface
Private iNSubs As Integer       ' Number of Subsegments
Private iNSSHS As Integer       ' # steady state heat sources
    ' Roughness data
Private sPerim(8) As String * 10
Private sRough(8) As String * 10
    ' This part for ECL Eval only
Private sWThk As String * 10    ' Wall Thickness
Private sWDist As String * 10   ' Distance between walls
Private sWCond As String * 10
Private sWDiff As String * 10
Private sSCond As String * 10
Private sSDiff As String * 10
Private sTSink As String * 10

    ' Collections of associated data
Private colSubs As New Collection          ' Collection of SubSegs
Private colSSHS As New Collection          ' Collection of Stead State Heat Sources

    ' Pointer to the parent section
Public Daddy As cSection

Public Function AddSSHS() As cSSHS
Dim ss As cSSHS
    Set ss = New cSSHS
    colSSHS.Add ss
    Set AddSSHS = ss
End Function

Public Function AddSubSeg() As cSubSeg
Dim ss As cSubSeg
    Set ss = New cSubSeg
    colSubs.Add ss
    Set AddSubSeg = ss
End Function

Public Sub setSubSegs(twall As String, tdry As String, twet As String)
' Set subsegment temperatures
Dim sss As cSubSeg
For Each sss In colSubs
    sss.updateSubSeg twall, tdry, twet
Next
End Sub

Public Sub ClearSSHS()
' Clear all steady state heat sources
Dim ii As Integer
For ii = 1 To colSSHS.Count
    colSSHS.Remove 1
Next ii

End Sub

Public Sub ClearSubs()
' Clear all subsegments
Dim ii As Integer
For ii = 1 To colSubs.Count
    colSubs.Remove 1
Next ii

End Sub

Property Get id() As Integer
    id = iID
    
End Property

Property Let id(ii As Integer)
    iID = ii
    
End Property

Public Sub SSHSList(gg As Grid)
' Load Steady State Heat Loads into gg
Dim ss As cSSHS
Dim n1 As Integer, n2 As Integer, nt As Integer
Dim HS As String, HL As String, id As String
    gg.AddItem " ", 0       ' add a blank row
    gg.Rows = 1             ' delete all but last
    For Each ss In colSSHS
        ss.getSSHS n1, n2, nt, HS, HL, id
        id = id + Chr(9) + Str(n1) + Chr(9) + Str(n2) + Chr(9) + Str(nt)
        id = id + Chr(9) + HS + Chr(9) + HL
        gg.AddItem id
    Next
    If gg.Rows > 1 Then
        gg.RemoveItem 0
        gg.AddItem " "
    End If

End Sub

Property Get sType() As Integer
    sType = iType
    
End Property

Property Let sType(ii As Integer)
    iType = ii
    
End Property

Public Sub SubList(gg As Grid)
' Load SubSegments into gg
Dim ss As cSubSeg
Dim xs As String
Dim n1 As Integer, n2 As Integer
Dim twall As String, tdry As String, twet As String
    gg.AddItem " ", 0       ' add a blank row
    gg.Rows = 1             ' delete all but last
    For Each ss In colSubs
        ss.getSubSeg n1, n2, twall, tdry, twet
        xs = Str$(n1) + Chr(9) + Str$(n2) + Chr(9) + twall + Chr(9) + _
           tdry + Chr(9) + twet
        gg.AddItem xs
    Next
    If gg.Rows > 1 Then
        gg.RemoveItem 0
        gg.AddItem " "
    End If

End Sub

Property Get Title() As String
    Title = szTitle
    
End Property

Property Let Title(ss As String)
    szTitle = ss
    
End Property

Property Get sLen() As String
    sLen = sSLen
    
End Property

Property Let sLen(ss As String)
    sSLen = ss
    
End Property

Public Sub WriteData()
' Write the segment data to the data file
Dim ii As Integer, jj As Integer
    Print #1, IStr(iID); IStr(iType); szTitle
    Print #1, sLen; sXArea; sHeight; IStr(iFire)
    ' Form 3B
    For ii = 1 To 7
        Print #1, sPerim(ii);
    Next ii
    Print #1, sPerim(8)
    For ii = 1 To 7
        Print #1, sRough(ii);
    Next ii
    Print #1, sRough(8)
    ' Form 3C
    jj = colSubs.Count
    iNSubs = colSubs(jj).SStop
    iNSSHS = colSSHS.Count
    Print #1, sHLFP; sHLFN; sHLBP; sHLBN; sWWS; IStr(NSubs); IStr(iNSSHS)
    ' Form 3D
    For ii = 1 To colSSHS.Count
        colSSHS(ii).WriteData
    Next ii
    ' Form 3E
    For ii = 1 To colSubs.Count
        colSubs(ii).WriteData
    Next ii
    'Form 3F
    If SESDS.ECLOpt > 0 Then
       Print #1, sWThk; sWDist; sWCond; sWDiff; sSCond; sSDiff; sTSink
    End If

End Sub

Property Get XArea() As String
    XArea = sXArea
    
End Property

Property Let XArea(ss As String)
    sXArea = ss
    
End Property

Property Get Height() As String
    Height = sHeight
    
End Property

Property Let Height(ss As String)
    sHeight = ss
    
End Property

Property Get Fire() As Integer
    Fire = iFire
    
End Property

Property Let Fire(ii As Integer)
    iFire = ii
    
End Property

Property Get HLFP() As String
    HLFP = sHLFP
    
End Property

Property Let HLFP(ss As String)
    sHLFP = ss
    
End Property

Property Get HLFN() As String
    HLFN = sHLFN
    
End Property

Property Let HLFN(ss As String)
    sHLFN = ss
    
End Property

Property Get HLBP() As String
    HLBP = sHLBP
    
End Property

Property Let HLBP(ss As String)
    sHLBP = ss
    
End Property

Property Get HLBN() As String
    HLBN = sHLBN
    
End Property

Property Let HLBN(ss As String)
    sHLBN = ss
    
End Property

Property Get WWS() As String
    WWS = sWWS
    
End Property

Property Let WWS(ss As String)
    sWWS = ss
    
End Property

Property Get NSubs() As Integer
    NSubs = colSubs(colSubs.Count).SStop
    
End Property

Property Let NSubs(ii As Integer)
    iNSubs = ii
    
End Property

Property Get NSSHS() As Integer
    NSSHS = iNSSHS
    
End Property

Property Let NSSHS(ii As Integer)
    iNSSHS = ii
    
End Property

Property Get Perim(i) As String
    Perim = sPerim(i)
    
End Property

Property Let Perim(i, ss As String)
    sPerim(i) = ss
    
End Property

Property Get Rough(i) As String
    Rough = sRough(i)
    
End Property

Property Let Rough(i, ss As String)
    sRough(i) = ss
    
End Property

Property Get WThk() As String
    WThk = sWThk
    
End Property

Property Let WThk(ss As String)
    sWThk = ss
    
End Property

Property Get WDist() As String
    WDist = sWDist
    
End Property

Property Let WDist(ss As String)
    sWDist = ss
    
End Property

Property Get WCond() As String
    WCond = sWCond
    
End Property

Property Let WCond(ss As String)
    sWCond = ss
    
End Property

Property Get WDiff() As String
    WDiff = sWDiff
    
End Property

Property Let WDiff(ss As String)
    sWDiff = ss
    
End Property

Property Get SCond() As String
    SCond = sSCond
    
End Property

Property Let SCond(ss As String)
    sSCond = ss
    
End Property

Property Get SDiff() As String
    SDiff = sSDiff
    
End Property

Property Let SDiff(ss As String)
    sSDiff = ss
    
End Property

Property Get TSink() As String
    TSink = sTSink
    
End Property

Property Let TSink(ss As String)
    sTSink = ss
    
End Property

Public Function SubSeg(ii As Integer) As cSubSeg
    Set SubSeg = colSubs.Item(ii)
    
End Function

Public Function SSHS(ii As Integer) As cSSHS
    Set SSHS = colSSHS.Item(ii)
    
End Function

Public Function ReadData() As Boolean
' Read the section record from the input file
Dim ix As Integer, j As Integer, k As Integer
Dim t1, t2, t3, t4, t5, t6, t7, t8
Dim LL$, L2$, Mark$
    ReadData = False
    On Error GoTo InErr
    Line Input #1, LL$
    iID = Val(Left$(LL$, 10))
    iType = Val(Mid$(LL$, 11, 10))
    szTitle = Mid$(LL$, 21, 36)
    
    If Not GetLine(t1, t2, t3, t4, t5, t6, t7, t8) Then Exit Function
    sSLen = t1
    sXArea = t2
    sHeight = t3
    iFire = Val(t4)
 '  3B
Mark$ = " Form 3B"
    Line Input #1, LL$
    Line Input #1, L2$
    For j = 1 To 8
        k = 10 * (j - 1) + 1
        sPerim(j) = Mid$(LL$, k, 10)
        sRough(j) = Mid$(L2$, k, 10)
    Next j
'  3C
Mark$ = " Form 3C"
    If Not GetLine(t1, t2, t3, t4, t5, t6, t7, t8) Then Exit Function
    sHLFP = t1
    sHLFN = t2
    sHLBP = t3
    sHLBN = t4
    sWWS = t5
    iNSubs = Val(t6)
    iNSSHS = Val(t7)
'  3D - Steady State Heat Sources
Mark$ = " Form 3D"
    Dim sh As cSSHS
    If iNSSHS > 0 Then
      For j = 1 To iNSSHS
        Set sh = New cSSHS
        If Not sh.ReadData Then Exit Function
        colSSHS.Add sh
      Next j
    End If
'  3E - SubSegments
Mark$ = " Form 3E"
    ix = 0
 ' These records are repeated until the ending subsegment
 '  number (NStop) is equal to the number of subsegments
 '  in this line segment.  It may be one or more records.
    Dim ss As cSubSeg
    ClearSubs
    Do
        Set ss = New cSubSeg
        If Not ss.ReadData Then Exit Function
        colSubs.Add ss
    Loop While (ss.SStop < iNSubs)

 '  3F - ECL Data
Mark$ = " Form 3F"
    If SESDS.ECLOpt > 0 Then
        If Not GetLine(t1, t2, t3, t4, t5, t6, t7, t8) Then Exit Function
        sWThk = t1
        sWDist = t2
        sWCond = t3
        sWDiff = t4
        sSCond = t5
        sSDiff = t6
        sTSink = t7
    End If
    ReadData = True
    Exit Function
InErr:
    ReadData = False
End Function
Public Sub XCopy(ssrc As cSegment)
' Copy the contents of segment ssrc to sdest
Dim ii As Integer
    With ssrc
        iType = .sType
        szTitle = .Title
        sSLen = .sLen
        sXArea = .XArea
        sHeight = .Height
        iFire = .Fire
        sHLFP = .HLFP
        sHLFN = .HLFN
        sHLBP = .HLBP
        sHLBN = .HLBN
        sWWS = .WWS
        iNSubs = .NSubs
        iNSSHS = .NSSHS
        For ii = 1 To 8
            sPerim(ii) = .Perim(ii)
            sRough(ii) = .Rough(ii)
        Next ii
        sWThk = .WThk
        sWDist = .WDist
        sWCond = .WCond
        sWDiff = .WDiff
        sSCond = .SCond
        sSDiff = .SDiff
        sTSink = .TSink
        ' Now copy wall data
        ' (first be sure the destination is empty)
        ClearSubs
        Dim ss As cSubSeg, sx As cSubSeg
        ii = 1
        Do
            Set ss = New cSubSeg
            ss.XCopy .SubSeg(ii)
            ii = ii + 1
            colSubs.Add ss
        Loop While (ss.SStop < iNSubs)
        
        ' and any steady-state heat sources
        ClearSSHS
        Dim sh As cSSHS
        For ii = 1 To iNSSHS
            Set sh = New cSSHS
            sh.XCopy .SSHS(ii)
            colSSHS.Add sh
        Next ii
    End With
End Sub


Public Sub XEdit(ssrc As cSegment)
' Copy the contents of segment ssrc to sdest
Dim ii As Integer
    With ssrc
        If .sType <> NA Then iType = .sType
        If .Title <> NA Then szTitle = .Title
        If .sLen <> NA Then sSLen = .sLen
        If .XArea <> NA Then sXArea = .XArea
        If .Height <> NA Then sHeight = .Height
        If .Fire <> NA Then iFire = .Fire
        If .HLFP <> NA Then sHLFP = .HLFP
        If .HLFN <> NA Then sHLFN = .HLFN
        If .HLBP <> NA Then sHLBP = .HLBP
        If .HLBN <> NA Then sHLBN = .HLBN
        If .WWS <> NA Then sWWS = .WWS
        If .NSubs <> NA Then iNSubs = .NSubs
        If .NSSHS <> NA Then iNSSHS = .NSSHS
        For ii = 1 To 8
            If .Perim(ii) <> NA Then sPerim(ii) = .Perim(ii)
            sRough(ii) = .Rough(ii)
        Next ii
        If .WThk <> NA Then sWThk = .WThk
        If .WDist <> NA Then sWDist = .WDist
        If .WCond <> NA Then sWCond = .WCond
        If .WDiff <> NA Then sWDiff = .WDiff
        If .SCond <> NA Then sSCond = .SCond
        If .SDiff <> NA Then sSDiff = .SDiff
        If .TSink <> NA Then sTSink = .TSink
        
   ' *** Wall Data and SSHS handling TBD
        ' Now copy wall data
        ' (first be sure the destination is empty)
'        ClearSubs
'        Dim ss As cSubSeg, sx As cSubSeg
'        ii = 1
'        Do
'            Set ss = New cSubSeg
'            ss.XCopy .SubSeg(ii)
'            ii = ii + 1
'            colSubs.Add ss
'        Loop While (ss.SStop < iNSubs)
'
'        ' and any steady-state heat sources
'        ClearSSHS
'        Dim sh As cSSHS
'        For ii = 1 To iNSSHS
'            Set sh = New cSSHS
'            sh.XCopy .SSHS(ii)
'            colSSHS.Add sh
'        Next ii
    End With
End Sub

Private Sub Class_Initialize()
Dim ss As cSubSeg, ii As Integer
    iID = 0
    iType = 1
    szTitle = ""
    sSLen = Zero
    sXArea = Zero
    sHeight = Zero
    iFire = 0
    sHLFP = Zero
    sHLFN = Zero
    sHLBP = Zero
    sHLBN = Zero
    sWWS = 0
    For ii = 1 To 8
        sPerim(ii) = Zero
        sRough(ii) = Zero
    Next ii
    sWThk = Zero
    sWDist = Zero
    sWCond = Zero
    sWDiff = Zero
    sSCond = Zero
    sSDiff = Zero
    sTSink = Zero
    Set ss = New cSubSeg
    colSubs.Add ss
    
End Sub

Private Sub Class_Terminate()
'    Release all subsegments and steady state heat sources
    ClearSubs
    ClearSSHS
    
End Sub

