VERSION 1.0 CLASS
BEGIN
  MultiUse = -1  'True
END
Attribute VB_Name = "cTrain"
Attribute VB_Creatable = False
Attribute VB_Exposed = False
' SESIN - Subway Environment Simulation Input Manager
' Volpe Transportation Systems Center
' Written by: ICF Kaiser Engineers, Oakland, CA
' Orig: Jan '97

Option Explicit

' Class cTrain

' This class contains train data.
' Objects of this class are contained in a cTrains object
' in SESDS

' Form 9A & 9E
' Physical Characteristics
Private sTrainId As String * 36 ' Train ID
Private iNCars As Integer       ' # Cars / Train
Private iNPwrd As Integer       ' # Powered Cars
Private sTLength As String * 10 ' Car Length
Private sAFront As String * 10  ' Frontal Area
Private sPerim As String * 10   ' Perimeter
Private sCWt As String * 10     ' avg car wt
Private iNMtr As Integer        ' motors/car

' Form 9B & 9E
' Resistance Terms
Private sCSkin As String * 10   ' Skin Fric Coeff
Private sCTruck As String * 10  ' Wtd Truck Area
Private sCFront As String * 10  ' Front drag coeff
Private sCRR1 As String * 10    ' Rolling Resist. Coeff.
Private sCRR2 As String * 10
Private sCRR3 As String * 10
Private sARRP As String * 10    ' Acc Resist of Rotating Parts

' Form 9C
' Heat Terms
Private sSensAuxE As String * 10    ' Sensible Heat Empty Car Aux.
Private sLatentAuxE As String * 10  ' Latent
Private sSensPac As String * 10     ' Sensible Heat / Passenger
Private sLatentPac As String * 10   ' Latent
Private sPwrAuxE As String * 10     ' Empty Aux Power
Private sPwrPac As String * 10      ' Aux Power / Passenger

' Form 9D
' Accelerating Resistor Grid Data
Private sArgWt As String * 10       ' Wt
Private sARGDia As String * 10      ' Diameter
Private sARGCArea As String * 10    ' Convection Area
Private sARGRArea As String * 10    ' Radiation Area
Private sARGEmm As String * 10      ' Emmisivity
Private sARGSpHt As String * 10     ' Specific Heat
Private sARGT0 As String * 10       ' Initial Temp
' Decelerating Resistor Grid Data
Private sDrgWt As String * 10       ' Wt
Private sDRGDia As String * 10      ' Diameter
Private sDRGCArea As String * 10    ' Convection Area
Private sDRGRArea As String * 10    ' Radiation Area
Private sDRGEmm As String * 10      ' Emmisivity
Private sDRGSpHt As String * 10     ' Specific Heat
Private sDRGT0 As String * 10       ' Initial Temp

' Form 9J Implicit Accel/Decel Data
Private sAMax As String * 10        ' Max allowable acceleration
Private sDV1 As String * 10         ' Normal Decel V1 to 0
Private sV1 As String * 10          ' Speed V1
Private sDV2 As String * 10         ' Normal Decel at V2
Private sV2 As String * 10          ' Speed V2

' Motor & Controller - Forms 9F,G, H, I
Public TMotor As cMotor
' FlyWheel - Forms 9K & L
Public TFlyWheel As cFlyWheel       ' Only allocated if required

Public Property Get id() As String
    id = sTrainId
    
End Property

Public Sub GetPhysical(ByRef sid As String, ByRef nCars As String, nPwrd As String, _
    nMtr As String, TLen As String, AFront As String, Perim As String, CWt As String)
    sid = sTrainId
    nCars = Str(iNCars)
    nPwrd = Str(iNPwrd)
    nMtr = Str(iNMtr)
    TLen = sTLength
    AFront = sAFront
    Perim = sPerim
    CWt = sCWt
    
End Sub

Public Sub SetPhysical(ByRef sid As String, ByRef nCars As String, nPwrd As String, _
    nMtr As String, TLen As String, AFront As String, Perim As String, CWt As String)
    sTrainId = sid
    iNCars = Val(nCars)
    iNPwrd = Val(nPwrd)
    iNMtr = Val(nMtr)
    sTLength = TLen
    sAFront = AFront
    sPerim = Perim
    sCWt = CWt
    
End Sub

Public Sub getResist(CSkin As String, CTruck As String, CFront As String, _
    CRR1 As String, CRR2 As String, CRR3 As String, ARRP As String)
    CSkin = sCSkin
    CTruck = sCTruck
    CFront = sCFront
    CRR1 = sCRR1
    CRR2 = sCRR2
    CRR3 = sCRR3
    ARRP = sARRP
    
End Sub

Public Sub setResist(CSkin As String, CTruck As String, CFront As String, _
    CRR1 As String, CRR2 As String, CRR3 As String, ARRP As String)
    sCSkin = CSkin
    sCTruck = CTruck
    sCFront = CFront
    sCRR1 = CRR1
    sCRR2 = CRR2
    sCRR3 = CRR3
    sARRP = ARRP
    
End Sub

Public Sub getHtLoads(SAux As String, LAux As String, sPac As String, _
    lPac As String, paux As String, ppac As String)
    SAux = sSensAuxE
    LAux = sLatentAuxE
    sPac = sSensPac
    lPac = sLatentPac
    paux = sPwrAuxE
    ppac = sPwrPac
    
End Sub

Public Sub setHtLoads(SAux As String, LAux As String, sPac As String, _
    lPac As String, paux As String, ppac As String)
    sSensAuxE = SAux
    sLatentAuxE = LAux
    sSensPac = sPac
    sLatentPac = lPac
    sPwrAuxE = paux
    sPwrPac = ppac
    
End Sub

Public Sub getRGrid(ss() As String)
' Get the Resistor grid data
    ss(0) = sArgWt
    ss(1) = sARGDia
    ss(2) = sARGCArea
    ss(3) = sARGRArea
    ss(4) = sARGEmm
    ss(5) = sARGSpHt
    ss(6) = sARGT0
    ss(7) = sDrgWt
    ss(8) = sDRGDia
    ss(9) = sDRGCArea
    ss(10) = sDRGRArea
    ss(11) = sDRGEmm
    ss(12) = sDRGSpHt
    ss(13) = sDRGT0
    
End Sub

Public Sub setRGrid(ss() As String)
' Get the Resistor grid data
    sArgWt = ss(0)
    sARGDia = ss(1)
    sARGCArea = ss(2)
    sARGRArea = ss(3)
    sARGEmm = ss(4)
    sARGSpHt = ss(5)
    sARGT0 = ss(6)
    sDrgWt = ss(7)
    sDRGDia = ss(8)
    sDRGCArea = ss(9)
    sDRGRArea = ss(10)
    sDRGEmm = ss(11)
    sDRGSpHt = ss(12)
    sDRGT0 = ss(13)
    
End Sub

Public Sub getRates(AMax As String, DV1 As String, V1 As String, _
    DV2 As String, V2 As String)
' Form 9J Data for Implicit Heat Calcs (TPOpt = 1)
    AMax = sAMax
    DV1 = sDV1
    V1 = sV1
    DV2 = sDV2
    V2 = sV2
    
End Sub

Public Sub setRates(AMax As String, DV1 As String, V1 As String, _
    DV2 As String, V2 As String)
' Form 9J Data for Implicit Heat Calcs (TPOpt = 1)
    sAMax = AMax
    sDV1 = DV1
    sV1 = V1
    sDV2 = DV2
    sV2 = V2
    
End Sub

Public Function ReadData() As Boolean
' Read Data for one train from the data file
Dim LL$, t1, t2, t3, t4, t5, t6, t7, t8
    ReadData = False
    On Error GoTo InErr
    Line Input #1, LL$
    sTrainId = Left$(LL$, 36)
    iNCars = Val(Mid$(LL$, 41, 10))
    iNPwrd = Val(Mid$(LL$, 51, 10))
    sTLength = Mid$(LL$, 61, 10)
    sAFront = Mid$(LL$, 71, 10)
    ' 9B
    If Not GetFour(t1, t2, t3, t4) Then Exit Function
    sPerim = t1
    sCSkin = t2
    sCTruck = t3
    sCFront = t4
    ' 9C
    If Not GetLine(t1, t2, t3, t4, t5, t6, t7, t8) Then Exit Function
    sSensAuxE = t1
    sLatentAuxE = t2
    sSensPac = t3
    sLatentPac = t4
    sPwrAuxE = t5
    sPwrPac = t6
    ' 9D
    If Not GetLine(t1, t2, t3, t4, t5, t6, t7, t8) Then Exit Function
    sArgWt = t1
    sDrgWt = t2
    sARGDia = t3
    sDRGDia = t4
    sARGCArea = t5
    sDRGCArea = t6
    sARGRArea = t7
    sDRGRArea = t8
    If Not GetLine(t1, t2, t3, t4, t5, t6, t7, t8) Then Exit Function
    sARGEmm = t1
    sDRGEmm = t2
    sARGSpHt = t3
    sDRGSpHt = t4
    sARGT0 = t5
    sDRGT0 = t6
    ' 9E
    If Not GetLine(t1, t2, t3, t4, t5, t6, t7, t8) Then Exit Function
    sCWt = t1
    iNMtr = t2
    sCRR1 = t3
    sCRR2 = t4
    sCRR3 = t5
    sARRP = t6
    If SESDS.TPOpt <> 3 Then
        If Not TMotor.ReadData Then Exit Function
    End If
    If SESDS.TPOpt = 1 Then
        '  9J
        If Not GetLine(t1, t2, t3, t4, t5, t6, t7, t8) Then Exit Function
        sAMax = t1
        sDV1 = t2
        sV1 = t3
        sDV2 = t4
        sV2 = t5
    End If
    If TMotor.FWOpt = 2 Then
        If Not TFlyWheel.ReadData Then Exit Function
    End If
    ReadData = True
    Exit Function
InErr:
    ReadData = False
    
End Function

Public Sub WriteData()
' Write data for one train
Dim ii As Integer
    Print #1, sTrainId; Tab(41); IStr(iNCars); IStr(iNPwrd); sTLength; sAFront
    Print #1, sPerim; sCSkin; sCTruck; sCFront
    Print #1, sSensAuxE; sLatentAuxE; sSensPac; sLatentPac; _
        sPwrAuxE; sPwrPac
    Print #1, sArgWt; sDrgWt; sARGDia; sDRGDia; _
        sARGCArea; sDRGCArea; sARGRArea; sDRGRArea
    Print #1, sARGEmm; sDRGEmm; sARGSpHt; sDRGSpHt; sARGT0; sDRGT0
    Print #1, sCWt; IStr(iNMtr); sCRR1; sCRR2; sCRR3; sARRP
    If SESDS.TPOpt <> 3 Then TMotor.WriteData
    If SESDS.TPOpt = 1 Then
        Print #1, sAMax; sDV1; sV1; sDV2; sV2
        If TMotor.FWOpt = 2 Then TFlyWheel.WriteData
    End If
    
End Sub

Public Sub XCopy(TT As cTrain)
' Copy the data from Train TT
Dim s1 As String, s2 As String, s3 As String, s0(20) As String
    With TT
        .GetPhysical sTrainId, s1, s2, s3, sTLength, sAFront, sPerim, sCWt
        iNCars = Val(s1)
        iNPwrd = Val(s2)
        iNMtr = Val(s3)
        .getResist sCSkin, sCTruck, sCFront, sCRR1, sCRR2, sCRR3, sARRP
        .getHtLoads sSensAuxE, sLatentAuxE, sSensPac, sLatentPac, sPwrAuxE, sPwrPac
        .getRGrid s0
        Me.setRGrid s0
        .getRates sAMax, sDV1, sV1, sDV2, sV2
        TMotor.XCopy .TMotor
        If TMotor.FWOpt = 2 Then TFlyWheel.XCopy .TFlyWheel
    End With
End Sub

Private Sub Class_Initialize()
    sTrainId = " "
    sTLength = Zero
    sAFront = Zero
    sPerim = Zero
    sCWt = Zero
    sCSkin = Zero
    sCTruck = Zero
    sCFront = Zero
    sCRR1 = "1.3"
    sCRR2 = "116."
    sCRR3 = "0.045"
    sARRP = "8.8"
    sSensAuxE = Zero
    sLatentAuxE = Zero
    sSensPac = Zero
    sLatentPac = Zero
    sPwrAuxE = Zero
    sPwrPac = Zero
    sArgWt = Zero
    sARGDia = Zero
    sARGCArea = Zero
    sARGRArea = Zero
    sARGEmm = Zero
    sARGSpHt = Zero
    sARGT0 = Zero
    sDrgWt = Zero
    sDRGDia = Zero
    sDRGCArea = Zero
    sDRGRArea = Zero
    sDRGEmm = Zero
    sDRGSpHt = Zero
    sDRGT0 = Zero
    sAMax = Zero
    sDV1 = Zero
    sV1 = Zero
    sDV2 = Zero
    sV2 = Zero
    
    Set TMotor = New cMotor
    Set TFlyWheel = New cFlyWheel
End Sub

Private Sub Class_Terminate()
    Set TMotor = Nothing
    Set TFlyWheel = Nothing
    
End Sub
